var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var encrypt_exports = {};
__export(encrypt_exports, {
  default: () => encrypt_default
});
module.exports = __toCommonJS(encrypt_exports);
var import_crypto = require("crypto");
var import_check_iv_length = __toESM(require("../lib/check_iv_length.js"));
var import_check_cek_length = __toESM(require("./check_cek_length.js"));
var import_buffer_utils = require("../lib/buffer_utils.js");
var import_cbc_tag = __toESM(require("./cbc_tag.js"));
var import_webcrypto = require("./webcrypto.js");
var import_crypto_key = require("../lib/crypto_key.js");
var import_is_key_object = __toESM(require("./is_key_object.js"));
var import_invalid_key_input = __toESM(require("../lib/invalid_key_input.js"));
var import_errors = require("../util/errors.js");
var import_ciphers = __toESM(require("./ciphers.js"));
var import_is_key_like = require("./is_key_like.js");
function cbcEncrypt(enc, plaintext, cek, iv, aad) {
  const keySize = parseInt(enc.slice(1, 4), 10);
  if ((0, import_is_key_object.default)(cek)) {
    cek = cek.export();
  }
  const encKey = cek.subarray(keySize >> 3);
  const macKey = cek.subarray(0, keySize >> 3);
  const algorithm = `aes-${keySize}-cbc`;
  if (!(0, import_ciphers.default)(algorithm)) {
    throw new import_errors.JOSENotSupported(`alg ${enc} is not supported by your javascript runtime`);
  }
  const cipher = (0, import_crypto.createCipheriv)(algorithm, encKey, iv);
  const ciphertext = (0, import_buffer_utils.concat)(cipher.update(plaintext), cipher.final());
  const macSize = parseInt(enc.slice(-3), 10);
  const tag = (0, import_cbc_tag.default)(aad, iv, ciphertext, macSize, macKey, keySize);
  return { ciphertext, tag };
}
function gcmEncrypt(enc, plaintext, cek, iv, aad) {
  const keySize = parseInt(enc.slice(1, 4), 10);
  const algorithm = `aes-${keySize}-gcm`;
  if (!(0, import_ciphers.default)(algorithm)) {
    throw new import_errors.JOSENotSupported(`alg ${enc} is not supported by your javascript runtime`);
  }
  const cipher = (0, import_crypto.createCipheriv)(algorithm, cek, iv, { authTagLength: 16 });
  if (aad.byteLength) {
    cipher.setAAD(aad, { plaintextLength: plaintext.length });
  }
  const ciphertext = cipher.update(plaintext);
  cipher.final();
  const tag = cipher.getAuthTag();
  return { ciphertext, tag };
}
const encrypt = (enc, plaintext, cek, iv, aad) => {
  let key;
  if ((0, import_webcrypto.isCryptoKey)(cek)) {
    (0, import_crypto_key.checkEncCryptoKey)(cek, enc, "encrypt");
    key = import_crypto.KeyObject.from(cek);
  } else if (cek instanceof Uint8Array || (0, import_is_key_object.default)(cek)) {
    key = cek;
  } else {
    throw new TypeError((0, import_invalid_key_input.default)(cek, ...import_is_key_like.types, "Uint8Array"));
  }
  (0, import_check_cek_length.default)(enc, key);
  (0, import_check_iv_length.default)(enc, iv);
  switch (enc) {
    case "A128CBC-HS256":
    case "A192CBC-HS384":
    case "A256CBC-HS512":
      return cbcEncrypt(enc, plaintext, key, iv, aad);
    case "A128GCM":
    case "A192GCM":
    case "A256GCM":
      return gcmEncrypt(enc, plaintext, key, iv, aad);
    default:
      throw new import_errors.JOSENotSupported("Unsupported JWE Content Encryption Algorithm");
  }
};
var encrypt_default = encrypt;
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {});
