var __create = Object.create;
var __defProp = Object.defineProperty;
var __getOwnPropDesc = Object.getOwnPropertyDescriptor;
var __getOwnPropNames = Object.getOwnPropertyNames;
var __getProtoOf = Object.getPrototypeOf;
var __hasOwnProp = Object.prototype.hasOwnProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};
var __copyProps = (to, from, except, desc) => {
  if (from && typeof from === "object" || typeof from === "function") {
    for (let key of __getOwnPropNames(from))
      if (!__hasOwnProp.call(to, key) && key !== except)
        __defProp(to, key, { get: () => from[key], enumerable: !(desc = __getOwnPropDesc(from, key)) || desc.enumerable });
  }
  return to;
};
var __toESM = (mod, isNodeMode, target) => (target = mod != null ? __create(__getProtoOf(mod)) : {}, __copyProps(isNodeMode || !mod || !mod.__esModule ? __defProp(target, "default", { value: mod, enumerable: true }) : target, mod));
var __toCommonJS = (mod) => __copyProps(__defProp({}, "__esModule", { value: true }), mod);
var ecdhes_exports = {};
__export(ecdhes_exports, {
  deriveKey: () => deriveKey,
  ecdhAllowed: () => ecdhAllowed,
  generateEpk: () => generateEpk
});
module.exports = __toCommonJS(ecdhes_exports);
var import_buffer_utils = require("../lib/buffer_utils.js");
var import_webcrypto = __toESM(require("./webcrypto.js"));
var import_crypto_key = require("../lib/crypto_key.js");
var import_invalid_key_input = __toESM(require("../lib/invalid_key_input.js"));
var import_is_key_like = require("./is_key_like.js");
async function deriveKey(publicKey, privateKey, algorithm, keyLength, apu = new Uint8Array(0), apv = new Uint8Array(0)) {
  if (!(0, import_webcrypto.isCryptoKey)(publicKey)) {
    throw new TypeError((0, import_invalid_key_input.default)(publicKey, ...import_is_key_like.types));
  }
  (0, import_crypto_key.checkEncCryptoKey)(publicKey, "ECDH");
  if (!(0, import_webcrypto.isCryptoKey)(privateKey)) {
    throw new TypeError((0, import_invalid_key_input.default)(privateKey, ...import_is_key_like.types));
  }
  (0, import_crypto_key.checkEncCryptoKey)(privateKey, "ECDH", "deriveBits");
  const value = (0, import_buffer_utils.concat)((0, import_buffer_utils.lengthAndInput)(import_buffer_utils.encoder.encode(algorithm)), (0, import_buffer_utils.lengthAndInput)(apu), (0, import_buffer_utils.lengthAndInput)(apv), (0, import_buffer_utils.uint32be)(keyLength));
  const sharedSecret = new Uint8Array(await import_webcrypto.default.subtle.deriveBits({
    name: "ECDH",
    public: publicKey
  }, privateKey, Math.ceil(parseInt(privateKey.algorithm.namedCurve.slice(-3), 10) / 8) << 3));
  return (0, import_buffer_utils.concatKdf)(sharedSecret, keyLength, value);
}
async function generateEpk(key) {
  if (!(0, import_webcrypto.isCryptoKey)(key)) {
    throw new TypeError((0, import_invalid_key_input.default)(key, ...import_is_key_like.types));
  }
  return import_webcrypto.default.subtle.generateKey(key.algorithm, true, ["deriveBits"]);
}
function ecdhAllowed(key) {
  if (!(0, import_webcrypto.isCryptoKey)(key)) {
    throw new TypeError((0, import_invalid_key_input.default)(key, ...import_is_key_like.types));
  }
  return ["P-256", "P-384", "P-521"].includes(key.algorithm.namedCurve);
}
// Annotate the CommonJS export names for ESM import in node:
0 && (module.exports = {
  deriveKey,
  ecdhAllowed,
  generateEpk
});
